@@ -117,11 +117,6 @@ EXPORT_SYMBOL(system_state);
  */
 #define MAX_INIT_ARGS CONFIG_INIT_ENV_ARG_LIMIT
 #define MAX_INIT_ENVS CONFIG_INIT_ENV_ARG_LIMIT
-#ifdef CONFIG_INIT_PASS_ALL_PARAMS
-#define INIT_PASS_FUNCTION pass_all_bootoptions
-#else
-#define INIT_PASS_FUNCTION pass_unknown_bootoptions
-#endif
 
 extern void time_init(void);
 /* Default late time init is NULL. archs can override this later. */
@@ -236,7 +231,7 @@ static int __init loglevel(char *str)
 early_param("loglevel", loglevel);
 
 /* Change NUL term back to "=", to make "param" the whole string. */
-static int __init repair_env_string(char *param, char *val, const char *unused, int known)
+static int __init repair_env_string(char *param, char *val, const char *unused)
 {
 	if (val) {
 		/* param=val or param="val"? */
@@ -253,20 +248,19 @@ static int __init repair_env_string(char *param, char *val, const char *unused,
 }
 
 /*
- * Select boot options to hand to init.  If all is set hand off them all
- * otherwise only hand off unused ones which do not apply to modules
- * (modprobe will find them in /proc/cmdline).
+ * Unknown boot options get handed to init, unless they look like
+ * unused parameters (modprobe will find them in /proc/cmdline).
  */
-static int __init pass_bootoption(char *param, char *val, const char *unused, int all)
+static int __init unknown_bootoption(char *param, char *val, const char *unused)
 {
-	repair_env_string(param, val, unused, all);
+	repair_env_string(param, val, unused);
 
 	/* Handle obsolete-style parameters */
-	if (obsolete_checksetup(param) && !all)
+	if (obsolete_checksetup(param))
 		return 0;
 
 	/* Unused module parameter. */
-	if (!all && strchr(param, '.') && (!val || strchr(param, '.') < val))
+	if (strchr(param, '.') && (!val || strchr(param, '.') < val))
 		return 0;
 
 	if (panic_later)
@@ -297,16 +291,6 @@ static int __init pass_bootoption(char *param, char *val, const char *unused, in
 	}
 	return 0;
 }
-static int __init pass_unknown_bootoptions(char *param, char *val, const char *unused, int known)
-{
-	if (known)
-		return 0;
-	return pass_bootoption(param, val, unused, 0);
-}
-static int __init pass_all_bootoptions(char *param, char *val, const char *unused, int known)
-{
-	return pass_bootoption(param, val, unused, 1);
-}
 
 static int __init init_setup(char *str)
 {
@@ -406,13 +390,10 @@ static noinline void __init_refok rest_init(void)
 }
 
 /* Check for early params. */
-static int __init do_early_param(char *param, char *val, const char *unused, int known)
+static int __init do_early_param(char *param, char *val, const char *unused)
 {
 	const struct obs_kernel_param *p;
 
-	if (known)
-		return 0;
-
 	for (p = __setup_start; p < __setup_end; p++) {
 		if ((p->early && parameq(param, p->str)) ||
 		    (strcmp(param, "console") == 0 &&
@@ -532,7 +513,7 @@ asmlinkage void __init start_kernel(void)
 	parse_early_param();
 	parse_args("Booting kernel", static_command_line, __start___param,
 		   __stop___param - __start___param,
-		   -1, -1, &INIT_PASS_FUNCTION);
+		   -1, -1, &unknown_bootoption);
 
 	jump_label_init();
 
